@@ -47,7 +47,7 @@ class SegmentMappingSim(MetadynamicSimulation):
                  time_per_iteration =10 * unit.nanosecond,
                  run_scans=True, run_production=True, input_scan_times=None, input_segment_coords=None,
                  max_iterations=15, max_coverage_criteria=.5, convergence_criteria=.1,
-                 retain_scan_bias=True, scan_CV_list=None,
+                 retain_scan_bias=True, retain_scan_coords=False, scan_CV_list=None,
                  **kwargs):
 
         super().__init__(**kwargs)
@@ -75,6 +75,7 @@ class SegmentMappingSim(MetadynamicSimulation):
         self.CV2_target_range = CV2_target_range
         self.max_iterations = max_iterations
         self.retain_scan_bias = retain_scan_bias
+        self.retain_scan_coords = retain_scan_coords
         self.max_coverage_criteria = max_coverage_criteria
         self.convergence_criteria = convergence_criteria
 
@@ -127,6 +128,7 @@ class SegmentMappingSim(MetadynamicSimulation):
 
             print('saving coords')
             initial_coords = self.positions
+            self.production_CV_list = self.CV_list
 
             self.scan_times = []
             self.segment_coords = []
@@ -142,7 +144,6 @@ class SegmentMappingSim(MetadynamicSimulation):
                     for match in matches:
                         os.remove(os.path.join(self.cwd, match.string))
 
-                self.production_CV_list = self.CV_list
                 if self.scan_CV_list is not None:
                     self.CV_list = self.scan_CV_list[i]
                     self._remove_custom_forces()
@@ -150,8 +151,9 @@ class SegmentMappingSim(MetadynamicSimulation):
 
                 print('Starting scan run for replica {}'.format(i+1))
 
-                self.simulation.context.reinitialize()
-                self.simulation.context.setPositions(initial_coords)
+                if self.retain_scan_coords == False:
+                    self.simulation.context.reinitialize()
+                    self.simulation.context.setPositions(self.positions)
 
                 nsteps = int(self.scan_time / self.step_length)
 
